# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class HostScanRecipe(object):
    """
    A host scan recipe (collection of host scanning configuration settings)
    """

    #: A constant which can be used with the lifecycle_state property of a HostScanRecipe.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a HostScanRecipe.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a HostScanRecipe.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a HostScanRecipe.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a HostScanRecipe.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a HostScanRecipe.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new HostScanRecipe object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this HostScanRecipe.
        :type id: str

        :param display_name:
            The value to assign to the display_name property of this HostScanRecipe.
        :type display_name: str

        :param compartment_id:
            The value to assign to the compartment_id property of this HostScanRecipe.
        :type compartment_id: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this HostScanRecipe.
            Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param time_created:
            The value to assign to the time_created property of this HostScanRecipe.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this HostScanRecipe.
        :type time_updated: datetime

        :param port_settings:
            The value to assign to the port_settings property of this HostScanRecipe.
        :type port_settings: oci.vulnerability_scanning.models.HostScanPortSettings

        :param agent_settings:
            The value to assign to the agent_settings property of this HostScanRecipe.
        :type agent_settings: oci.vulnerability_scanning.models.HostScanAgentSettings

        :param application_settings:
            The value to assign to the application_settings property of this HostScanRecipe.
        :type application_settings: oci.vulnerability_scanning.models.ApplicationScanSettings

        :param schedule:
            The value to assign to the schedule property of this HostScanRecipe.
        :type schedule: oci.vulnerability_scanning.models.Schedule

        :param freeform_tags:
            The value to assign to the freeform_tags property of this HostScanRecipe.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this HostScanRecipe.
        :type defined_tags: dict(str, dict(str, object))

        :param system_tags:
            The value to assign to the system_tags property of this HostScanRecipe.
        :type system_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'display_name': 'str',
            'compartment_id': 'str',
            'lifecycle_state': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'port_settings': 'HostScanPortSettings',
            'agent_settings': 'HostScanAgentSettings',
            'application_settings': 'ApplicationScanSettings',
            'schedule': 'Schedule',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'system_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'display_name': 'displayName',
            'compartment_id': 'compartmentId',
            'lifecycle_state': 'lifecycleState',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'port_settings': 'portSettings',
            'agent_settings': 'agentSettings',
            'application_settings': 'applicationSettings',
            'schedule': 'schedule',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'system_tags': 'systemTags'
        }

        self._id = None
        self._display_name = None
        self._compartment_id = None
        self._lifecycle_state = None
        self._time_created = None
        self._time_updated = None
        self._port_settings = None
        self._agent_settings = None
        self._application_settings = None
        self._schedule = None
        self._freeform_tags = None
        self._defined_tags = None
        self._system_tags = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this HostScanRecipe.
        Unique identifier of the config that is immutable on creation


        :return: The id of this HostScanRecipe.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this HostScanRecipe.
        Unique identifier of the config that is immutable on creation


        :param id: The id of this HostScanRecipe.
        :type: str
        """
        self._id = id

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this HostScanRecipe.
        Recipe identifier, which can be renamed


        :return: The display_name of this HostScanRecipe.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this HostScanRecipe.
        Recipe identifier, which can be renamed


        :param display_name: The display_name of this HostScanRecipe.
        :type: str
        """
        self._display_name = display_name

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this HostScanRecipe.
        Compartment ID of the scan recipe


        :return: The compartment_id of this HostScanRecipe.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this HostScanRecipe.
        Compartment ID of the scan recipe


        :param compartment_id: The compartment_id of this HostScanRecipe.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this HostScanRecipe.
        The current state of the config.

        Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this HostScanRecipe.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this HostScanRecipe.
        The current state of the config.


        :param lifecycle_state: The lifecycle_state of this HostScanRecipe.
        :type: str
        """
        allowed_values = ["CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this HostScanRecipe.
        Date and time the recipe was created, format as described in `RFC 3339`__

        __ https://tools.ietf.org/rfc/rfc3339


        :return: The time_created of this HostScanRecipe.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this HostScanRecipe.
        Date and time the recipe was created, format as described in `RFC 3339`__

        __ https://tools.ietf.org/rfc/rfc3339


        :param time_created: The time_created of this HostScanRecipe.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        **[Required]** Gets the time_updated of this HostScanRecipe.
        Date and time the recipe was last updated, format as described in `RFC 3339`__

        __ https://tools.ietf.org/rfc/rfc3339


        :return: The time_updated of this HostScanRecipe.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this HostScanRecipe.
        Date and time the recipe was last updated, format as described in `RFC 3339`__

        __ https://tools.ietf.org/rfc/rfc3339


        :param time_updated: The time_updated of this HostScanRecipe.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def port_settings(self):
        """
        **[Required]** Gets the port_settings of this HostScanRecipe.

        :return: The port_settings of this HostScanRecipe.
        :rtype: oci.vulnerability_scanning.models.HostScanPortSettings
        """
        return self._port_settings

    @port_settings.setter
    def port_settings(self, port_settings):
        """
        Sets the port_settings of this HostScanRecipe.

        :param port_settings: The port_settings of this HostScanRecipe.
        :type: oci.vulnerability_scanning.models.HostScanPortSettings
        """
        self._port_settings = port_settings

    @property
    def agent_settings(self):
        """
        **[Required]** Gets the agent_settings of this HostScanRecipe.

        :return: The agent_settings of this HostScanRecipe.
        :rtype: oci.vulnerability_scanning.models.HostScanAgentSettings
        """
        return self._agent_settings

    @agent_settings.setter
    def agent_settings(self, agent_settings):
        """
        Sets the agent_settings of this HostScanRecipe.

        :param agent_settings: The agent_settings of this HostScanRecipe.
        :type: oci.vulnerability_scanning.models.HostScanAgentSettings
        """
        self._agent_settings = agent_settings

    @property
    def application_settings(self):
        """
        Gets the application_settings of this HostScanRecipe.

        :return: The application_settings of this HostScanRecipe.
        :rtype: oci.vulnerability_scanning.models.ApplicationScanSettings
        """
        return self._application_settings

    @application_settings.setter
    def application_settings(self, application_settings):
        """
        Sets the application_settings of this HostScanRecipe.

        :param application_settings: The application_settings of this HostScanRecipe.
        :type: oci.vulnerability_scanning.models.ApplicationScanSettings
        """
        self._application_settings = application_settings

    @property
    def schedule(self):
        """
        **[Required]** Gets the schedule of this HostScanRecipe.

        :return: The schedule of this HostScanRecipe.
        :rtype: oci.vulnerability_scanning.models.Schedule
        """
        return self._schedule

    @schedule.setter
    def schedule(self, schedule):
        """
        Sets the schedule of this HostScanRecipe.

        :param schedule: The schedule of this HostScanRecipe.
        :type: oci.vulnerability_scanning.models.Schedule
        """
        self._schedule = schedule

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this HostScanRecipe.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this HostScanRecipe.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this HostScanRecipe.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this HostScanRecipe.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this HostScanRecipe.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this HostScanRecipe.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this HostScanRecipe.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this HostScanRecipe.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def system_tags(self):
        """
        Gets the system_tags of this HostScanRecipe.
        Usage of system tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`


        :return: The system_tags of this HostScanRecipe.
        :rtype: dict(str, dict(str, object))
        """
        return self._system_tags

    @system_tags.setter
    def system_tags(self, system_tags):
        """
        Sets the system_tags of this HostScanRecipe.
        Usage of system tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`


        :param system_tags: The system_tags of this HostScanRecipe.
        :type: dict(str, dict(str, object))
        """
        self._system_tags = system_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
